Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(10)

Unified Diff: src/heap.h

Issue 7366: Split window support from V8. ... (Closed) Base URL: http://v8.googlecode.com/svn/branches/bleeding_edge/
Patch Set: '' Created 12 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/handles.cc ('k') | src/heap.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/heap.h
===================================================================
--- src/heap.h (revision 539)
+++ src/heap.h (working copy)
@@ -280,12 +280,12 @@
// Please note this does not perform a garbage collection.
static Object* AllocateFunctionPrototype(JSFunction* function);
// Reinitialize a JSGlobalObject based on a constructor. The JSObject
// must have the same size as objects allocated using the
- // constructor. The JSObject is reinitialized and behaves as an
+ // constructor. The object is reinitialized and behaves as an
// object that has been freshly allocated using the constructor.
- static Object* ReinitializeJSGlobalObject(JSFunction* constructor,
- JSGlobalObject* global);
+ static Object* ReinitializeJSGlobalProxy(JSFunction* constructor,
+ JSGlobalProxy* global);
// Allocates and initializes a new JavaScript object based on a map.
// Returns Failure::RetryAfterGC(requested_bytes, space) if the allocation
« no previous file with comments | « src/handles.cc ('k') | src/heap.cc » ('j') | no next file with comments »
@@ -280,12 +280,12 @@
// Please note this does not perform a garbage collection.
static Object* AllocateFunctionPrototype(JSFunction* function);
- // Reinitialize a JSGlobalObject based on a constructor. The JSObject
+ // Reinitialize an JSGlobalProxy based on a constructor. The object
// must have the same size as objects allocated using the

Powered by Google App Engine
This is Rietveld 408576698